@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -205,6 +205,7 @@ class ExcelWriter(object):
         self.book = openpyxl.Workbook()
         self.sheet = self.book.active
         if sheet_title:
+            sheet_title = sheet_title.replace('/', '-')
             self.sheet.title = sheet_title
         self.number_formats = number_formats
         self.highlight_rows = highlight_rows
@@ -233,16 +234,18 @@ class ExcelWriter(object):
     def disable_grid_lines(self, sheet=None):
         self.enable_grid_lines(sheet=sheet, enabled=False)
 
-    def write_header(self, labels=None):
+    def write_header(self, labels=None, sheet=None):
+        if not sheet:
+            sheet = self.sheet
         font = Font(bold=True)
         for i, field in enumerate(self.fields, 1):
             value = field
             if labels and field in labels:
                 value = labels[field]
-            cell = self.sheet.cell(row=1, column=i, value=value)
+            cell = sheet.cell(row=1, column=i, value=value)
             cell.font = font
 
-    def write_row(self, data, row=None):
+    def write_row(self, data, row=None, sheet=None):
         """
         Write (append) a single data row to the current sheet.
 
@@ -251,13 +254,16 @@ class ExcelWriter(object):
         if row is None:
             raise NotImplementedError("should be able to detect 'next' row here?")
 
-        self.sheet.append(data)
+        if not sheet:
+            sheet = self.sheet
+
+        sheet.append(data)
 
         # apply number formats
         if self.number_formats:
             for col, field in enumerate(self.fields, 1):
                 if field in self.number_formats:
-                    cell = self.sheet.cell(row=row, column=col)
+                    cell = sheet.cell(row=row, column=col)
                     cell.number_format = self.number_formats[field]
 
         # apply row highlighting
@@ -267,19 +273,21 @@ class ExcelWriter(object):
                                         fgColor='d9d9d9',
                                         bgColor='d9d9d9')
                 for col, field in enumerate(self.fields, 1):
-                    cell = self.sheet.cell(row=row, column=col)
+                    cell = sheet.cell(row=row, column=col)
                     cell.fill = fill_even
 
-    def write_rows(self, rows, progress=None):
+    def write_rows(self, rows, sheet=None, progress=None):
         """
         Write (append) a sequence of data rows to the current sheet.
         """
         def write(data, i):
             # must add 1 to account for header
-            self.write_row(data, row=i + 1)
+            self.write_row(data, row=i + 1, sheet=sheet)
 
-        progress_loop(write, rows, progress,
-                      message="Generating cells for spreadsheet")
+        msg = "Generating cells for sheet"
+        if sheet:
+            msg = "{}: {}".format(msg, sheet.title)
+        progress_loop(write, rows, progress, message=msg)
 
     def auto_freeze(self, row=2, column=1):
         """
