@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -200,13 +200,22 @@ class PeopleHandler(GenericHandler, MergeMixin):
         if email not in person.emails:
             raise ValueError("Email does not belong to this person.")
 
+        address_changed = False
         if 'address' in kwargs:
-            email.address = kwargs['address']
+            address = kwargs['address']
+            if self.should_force_email_to_lower_case():
+                address = address.lower()
+            if email.address != address:
+                email.address = address
+                address_changed = True
 
         if 'type' in kwargs:
             email.type = kwargs['type']
 
-        if 'invalid' in kwargs:
+        if address_changed:
+            if email.invalid:
+                email.invalid = False
+        elif 'invalid' in kwargs:
             email.invalid = kwargs['invalid']
 
         if 'preferred' in kwargs:
@@ -219,6 +228,11 @@ class PeopleHandler(GenericHandler, MergeMixin):
 
         return email
 
+    def should_force_email_to_lower_case(self):
+        return self.config.getbool('rattail',
+                                   'people.should_force_email_to_lower_case',
+                                   default=False)
+
     def add_address(self, person, type=None,
                     street=None, street2=None,
                     city=None, state=None, zipcode=None,
